@@ -22,10 +22,6 @@ gp <- format_multidog(x = uit, varname = paste0("Pr_", 0:ploidy))
 class(gp)
 dim(gp)
 
-## -----------------------------------------------------------------------------
-gl <- format_multidog(x = uit, varname = paste0("logL_", 0:ploidy))
-gp2 <- gl_to_gp(gl = gl)
-
 ## -----------------------------------------------------------------------------
 ldout <- ldfast(gp = gp, type = "r2")
 
